@@ -35,3 +35,22 @@ CREATE TABLE IF NOT EXISTS simpleblog_t_comment
                    , `blog_id`
                    )
 ) ENGINE=InnoDB CHARACTER SET utf8;
+
+CREATE TABLE IF NOT EXISTS simpleblog_t_trackback
+(
+      `ctime`              datetime       NOT NULL
+    , `cuser`              varchar(255)   NOT NULL
+    , `mtime`              datetime       NOT NULL
+    , `muser`              varchar(255)   NOT NULL
+    , `trackback_id`       int unsigned   NOT NULL
+    , `blog_id`            int unsigned   NOT NULL
+    , `url`                text           NOT NULL
+    , `blogname`           text
+    , `title`              text
+    , `body`               text
+    , `status`             int unsigned
+    , PRIMARY KEY  (
+                     `trackback_id`
+                   , `blog_id`
+                   )
+) ENGINE=InnoDB CHARACTER SET utf8;
